==> myfaces-core-assembly-2.2.15-src.zip: myfaces-core-module-2.2.15/api/src/main/java/javax/faces/component/visit/VisitContextWrapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.faces.component.visit;

import java.util.Collection;
import java.util.Set;

import javax.faces.FacesWrapper;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;

/**
 * @since 2.0
 */
public abstract class VisitContextWrapper extends VisitContext implements FacesWrapper<VisitContext>
{

    /**
     * 
     */
    public VisitContextWrapper()
    {
        
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public FacesContext getFacesContext()
    {
        return getWrapped().getFacesContext();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Set<VisitHint> getHints()
    {
        return getWrapped().getHints();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Collection<String> getIdsToVisit()
    {
        return getWrapped().getIdsToVisit();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Collection<String> getSubtreeIdsToVisit(UIComponent component)
    {
        return getWrapped().getSubtreeIdsToVisit(component);
    }
    
    public abstract VisitContext getWrapped();

    /**
     * {@inheritDoc}
     */
    @Override
    public VisitResult invokeVisitCallback(UIComponent component, VisitCallback callback)
    {
        return getWrapped().invokeVisitCallback(component, callback);
    }

}

==> myfaces-core-assembly-2.3.9-src.zip: myfaces-core-module-2.3.9/api/src/main/java/javax/faces/component/visit/VisitContextWrapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.faces.component.visit;

import java.util.Collection;
import java.util.Set;

import javax.faces.FacesWrapper;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;

/**
 * @since 2.0
 */
public abstract class VisitContextWrapper extends VisitContext implements FacesWrapper<VisitContext>
{
    private VisitContext delegate;

    @Deprecated
    public VisitContextWrapper()
    {
        
    }

    public VisitContextWrapper(VisitContext delegate)
    {
        this.delegate = delegate;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public FacesContext getFacesContext()
    {
        return getWrapped().getFacesContext();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Set<VisitHint> getHints()
    {
        return getWrapped().getHints();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Collection<String> getIdsToVisit()
    {
        return getWrapped().getIdsToVisit();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Collection<String> getSubtreeIdsToVisit(UIComponent component)
    {
        return getWrapped().getSubtreeIdsToVisit(component);
    }
    
    public VisitContext getWrapped()
    {
        return delegate;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public VisitResult invokeVisitCallback(UIComponent component, VisitCallback callback)
    {
        return getWrapped().invokeVisitCallback(component, callback);
    }

}
